@@ -3,8 +3,8 @@
 #' @templateVar fn Scalar
 #' @template x
 #' @template na-handling
-#' @param na.ok [\code{logical(1)}]\cr
-#'  Are missing values allowed? Default is \code{FALSE}.
+#' @template na.ok
+#' @template null.ok
 #' @template checker
 #' @family scalars
 #' @useDynLib checkmate c_check_scalar
@@ -12,15 +12,19 @@
 #' @examples
 #' testScalar(1)
 #' testScalar(1:10)
-checkScalar = function(x, na.ok = FALSE) {
-  .Call(c_check_scalar, x, na.ok)
+checkScalar = function(x, na.ok = FALSE, null.ok = FALSE) {
+  .Call(c_check_scalar, x, na.ok, null.ok)
 }
 
+#' @export
+#' @rdname checkScalar
+check_scalar = checkScalar
+
 #' @export
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkScalar
-assertScalar = makeAssertionFunction(checkScalar, c.fun = "c_check_scalar")
+assertScalar = makeAssertionFunction(checkScalar, c.fun = "c_check_scalar", use.namespace = FALSE)
 
 #' @export
 #' @rdname checkScalar
@@ -39,4 +43,4 @@ test_scalar = testScalar
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkScalar
-expect_scalar = makeExpectationFunction(checkScalar, c.fun = "c_check_scalar")
+expect_scalar = makeExpectationFunction(checkScalar, c.fun = "c_check_scalar", use.namespace = FALSE)
